@@ -49,9 +49,9 @@ class SunGridEngineCommands(object):
         df_running_jobs = pandas.DataFrame(leaf_to_dict(leaf=tree[0]))
         df_pending_jobs = pandas.DataFrame(leaf_to_dict(leaf=tree[1]))
         df_merge = df_running_jobs.append(df_pending_jobs, sort=True)
-        df_merge.state[df_merge.state == "r"] = "running"
-        df_merge.state[df_merge.state == "qw"] = "pending"
-        df_merge.state[df_merge.state == "Eqw"] = "error"
+        df_merge.loc[df_merge.state == "r", 'state'] = "running"
+        df_merge.loc[df_merge.state == "qw", 'state'] = "pending"
+        df_merge.loc[df_merge.state == "Eqw", 'state'] = "error"
         return pandas.DataFrame(
             {
                 "jobid": pandas.to_numeric(df_merge.JB_job_number),
